@@ -7,7 +7,7 @@ class ISampleScriptCrawl:
     """
 
     @abstractmethod
-    def do_crawl(params:dict):
+    def do_crawl(self,params:dict):
         """
         抓取的业务逻辑
         :return: 返回一个 OutputWrapper的 数组
